#!/bin/sh
###############################################################################
##
##  Module install script
##
###############################################################################

modName=MEDIATOMB

###############################################################################
##
##  Include module library
##
###############################################################################
shellDir="/raid/data/module/$modName/Shell"
[ ! -d "$shellDir" -o ! -r "$shellDir/module.lib" ] && shellDir=/raid/data/tmp/module/Shell
{ [ -r "$shellDir/module.lib" ] && source "$shellDir/module.lib"; } || { echo fail; exit 1; }

###############################################################################
##
##  Start the module installation
##
###############################################################################
ModuleInstallStart

###############################################################################
##
##  Module specific installation stuff
##
###############################################################################
# Do the initial configuration of the mediatomb server

# Set UUID
UUID=$(cat /proc/sys/kernel/random/uuid)
echo "Setting initial UUID to randomly generated string: $UUID" >>$modLog
sed -i -e "s/@@@UUID@@@/$UUID/" $modDir/system/etc/config.xml
unset UUID

# Set hostname
echo "Setting display name of mediatomb: $(hostname -f)" >>$modLog
sed -i -e "s/@@@NAME@@@/$(hostname -f)/" $modDir/system/etc/config.xml

# Set interface to bind to
IF_MODE=$(/opt/bin/sqlite /app/cfg/conf.db "SELECT v FROM conf WHERE k = 'nic1_mode_8023ad';")
if [ "$IF_MODE" != "none" ]; then
	echo "Interface bonding mode is $IF_MODE. Bonding detected, binding mediatomb service to bond0" >>$modLog
	sed -i -e "s/@@@INTERFACE@@@/bond0/" $modDir/system/etc/config.xml
else
	echo "Interface bonding mode is $IF_MODE. No bonding detected, binding mediatomb service to WAN interface" >>$modLog
	sed -i -e "s/@@@INTERFACE@@@/eth0/" $modDir/system/etc/config.xml
fi

###############################################################################
##
##  Finish module installation indicating success
##
###############################################################################
ModuleInstallEnd 0

